// 
// SVEhaClose is Copyright (C) 2013, Sylvain Vervoort <stocata.org>.
// stocata.org reserves the right to modify/overwrite this NinjaScript with each release.
// Release V1.0 July, 2012.

#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
/// <summary>
/// The average heikin-ashi closing price.
/// </summary>
[Description("")]
public class SVEhaClose : Indicator
{
    #region Variables

	private DataSeries 		haOpen;		// heikin ashi open price
	private DataSeries 		haC;		// heikin ashi closing price

    #endregion

    /// <summary>
    /// Configuring the indicator called once before any bar data.
    /// </summary>
    protected override void Initialize()
    {	
		Add(new Plot(Color.Black, "haC"));
		haOpen 	= new DataSeries(this);
		haC 	= new DataSeries(this);
		
		PaintPriceMarkers 	= false;
		Overlay				= true;
    }

    /// <summary>
    /// Called on each bar update event (incoming tick)
    /// </summary>
    protected override void OnBarUpdate()
    {	
		if (CurrentBar < 1) // minimum 2 bars required
			return;
		
		// Create average heikin-ashi closing price
		haOpen.Set((((Open[1] + High[1] + Low[1] + Close[1]) / 4) + haOpen[1]) / 2);
		Value.Set(((Open[0] + High[0] + Low[0] + Close[0]) / 4 + haOpen[0] + 
				  Math.Max(High[0], haOpen[0]) + Math.Min(Low[0], haOpen[0])) / 4);
    }

    #region Properties

	#endregion
}
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SVEhaClose[] cacheSVEhaClose = null;

        private static SVEhaClose checkSVEhaClose = new SVEhaClose();

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public SVEhaClose SVEhaClose()
        {
            return SVEhaClose(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public SVEhaClose SVEhaClose(Data.IDataSeries input)
        {
            if (cacheSVEhaClose != null)
                for (int idx = 0; idx < cacheSVEhaClose.Length; idx++)
                    if (cacheSVEhaClose[idx].EqualsInput(input))
                        return cacheSVEhaClose[idx];

            lock (checkSVEhaClose)
            {
                if (cacheSVEhaClose != null)
                    for (int idx = 0; idx < cacheSVEhaClose.Length; idx++)
                        if (cacheSVEhaClose[idx].EqualsInput(input))
                            return cacheSVEhaClose[idx];

                SVEhaClose indicator = new SVEhaClose();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                SVEhaClose[] tmp = new SVEhaClose[cacheSVEhaClose == null ? 1 : cacheSVEhaClose.Length + 1];
                if (cacheSVEhaClose != null)
                    cacheSVEhaClose.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheSVEhaClose = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SVEhaClose SVEhaClose()
        {
            return _indicator.SVEhaClose(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.SVEhaClose SVEhaClose(Data.IDataSeries input)
        {
            return _indicator.SVEhaClose(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SVEhaClose SVEhaClose()
        {
            return _indicator.SVEhaClose(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.SVEhaClose SVEhaClose(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SVEhaClose(input);
        }
    }
}
#endregion
